<div style="background-color: #303d50; min-height:25px; border-radius: 0px; margin: 0; width:100%">
    <p style="font-size: 20px; color: white; font-weight: 500; text-align: left; margin: 0 20px; padding: 5px 0">
        {{ titulo }}
    </p>
</div>
