<div class="columna" style="padding-top: 0px; padding-bottom: 0px;">
    <p  style=" font-size: 11px; color: #002857; font-weight: 500; text-align: justify; margin: 0px 20px 0px 20px">
        {{encasode}}
    </p>
</div>
