<style>
  .tabla-proyecto {
    width: 91.5%;
    border-collapse: collapse;
    margin: 50px 40px 20px 40px; /* top, right, bottom, left */
  }

  .tabla-proyecto th,
  .tabla-proyecto td {
    border: 1px solid #ccc;
    padding: 8px;
    text-align: center;
    font-size: 14px;
  }

  .tabla-proyecto th {
    background-color: #f0f0f0;
  }
</style>


<table class="tabla-proyecto">
  <tr>
    <th>Proyecto</th>
    <th>Nombre</th>
    <th>Firma</th>
    <th>Fecha</th>
  </tr>
  {% for fila in filas %}
  <tr>
    <td>{{ fila.rol }}</td>
    <td>{{ fila.nombre }}</td>
    <td>{{ fila.firma }}</td>
    <td>{{ fila.fecha }}</td>
  </tr>
  {% endfor %}
</table>
