<table>
  <tr>
    <td class="celda-u" style="width: 960px;">
      <label>{{ label }}</label>
      <textarea style="width: {{ ancho|default:'100%' }}; height: {{ alto|default:'200px' }}; padding: 10px; border: 1px solid #ccc; border-radius: 5px; font-family: 'Roboto', sans-serif;"
          readonly>{{ valor|default:'' }}</textarea>
    </td>
  </tr>
</table>
