<div style="background-color: #303d50; min-height:25px; width: 100%; margin: 10px 0;">
    <p style="font-size: 18px; color: white; font-weight: 700; text-align: left; margin: 0 20px; padding: 10px 10px 10px 0;">
      {{ titulo }}
    </p>
</div>
  