<div style="background-color: #303d50; min-height:25px; width: 100%; margin: 0; border-radius: 5px, 5px;">
    <p style="font-size: 18px; color: white; font-weight: 700; text-align: left; margin: 0 20px; padding: 10px 10px 10px 0;">
      Anexos
    </p>
</div>
<div class="especial" style=" width: 96%; margin-top: 10px; padding-bottom: 5px;">
    <table>
        <tr>
            <table>
                <tr>
                    <td class="celda-i"
                        style="width: 2px; padding-top: none; padding-bottom: 0px; padding-right: 0px;">
                        <label style="padding-top: 0px; margin-bottom: 0px;" for="radicado">1.</label>
                    </td>
                    {% if documento_identidad is not None %}
                    <td class="celda-c" style="width: 392px; padding-left: 0px;">

                        <input style=" min-height: 20px; background: white; border: none; border-bottom-style: solid; border-radius: 0px;
                            border-color: #002857; border-width: 1px;" type="text" id="radicado" name="radicado"
                            value='Cédula de ciudadanía: Adjunta'>
                    </td>
                    {% else %}
                    <td class="celda-c" style="width: 392px; padding-left: 0px;">
                        <input style=" min-height: 20px; background: white; border: none; border-bottom-style: solid; border-radius: 0px;
                            border-color: #002857; border-width: 1px;" type="text" id="radicado" name="radicado"
                            value='Cédula de ciudadanía: No adjunta'>
                    </td>
                    {% endif %}
                </tr>
                <tr>
                    <td class="celda-i"
                        style="width: 2px; padding-top: none; padding-bottom: 0px; padding-right: 0px;">
                        <label style="padding-top: 0px; margin-bottom: 0px;" for="radicado">2.</label>
                    </td>
                    {% if documento_apoderado is not None %}
                    <td class="celda-c" style="width: 392px; padding-left: 0px;">
                        <input style=" min-height: 20px; background: white; border: none; border-bottom-style: solid; border-radius: 0px;
                            border-color: #002857; border-width: 1px;" type="text" id="radicado" name="radicado"
                            value='Documento del apoderado: Adjunta'>
                    </td>
                    {% else %}
                    <td class="celda-c" style="width: 392px; padding-left: 0px;">
                        <input style=" min-height: 20px; background: white; border: none; border-bottom-style: solid; border-radius: 0px;
                            border-color: #002857; border-width: 1px;" type="text" id="radicado" name="radicado"
                            value='Documento del apoderado: No adjunta'>
                    </td>
                    {% endif %}
                </tr>
                <tr>
                    <td class="celda-i"
                        style="width: 2px; padding-top: none; padding-bottom: 0px; padding-right: 0px;">
                        <label style="padding-top: 0px; margin-bottom: 0px;" for="radicado">3.</label>
                    </td>
                    {% if escrito is not None %}
                    <td class="celda-c" style="width: 392px; padding-left: 0px;">
                        <input style=" min-height: 20px; background: white; border: none; border-bottom-style: solid ; border-radius: 0px;
                            border-color: #002857 ; border-width: 1px;" type="text" id="radicado" name="radicado"
                            value='Escrito de inconformidad: Adjunta'>
                    </td>
                    {% else %}
                    <td class="celda-c" style="width: 392px; padding-left: 0px;">
                        <input style=" min-height: 20px; background: white; border: none; border-bottom-style: solid ; border-radius: 0px;
                            border-color: #002857 ; border-width: 1px;" type="text" id="radicado" name="radicado"
                            value='Escrito de inconformidad: No adjunta'>
                    </td>
                    {% endif %}
                </tr>
                <tr>
                    <td class="celda-i"
                        style="width: 2px; padding-top: none; padding-bottom: 0px; padding-right: 0px;">
                        <label style="padding-top: 0px; margin-bottom: 0px;" for="radicado">4.</label>
                    </td>
                    {% if anexo is not None %}
                    <td class="celda-c" style="width: 392px; padding-left: 0px;">
                        <input style=" min-height: 20px; background: white; border: none; border-bottom-style: solid; border-radius: 0px;
                            border-color: #002857; border-width: 1px;" type="text" id="radicado" name="radicado"
                            value='Evidencias: Adjunta'>
                    </td>
                    {% else %}
                    <td class="celda-c" style="width: 392px; padding-left: 0px;">
                        <input style=" min-height: 20px; background: white; border: none; border-bottom-style: solid; border-radius: 0px;
                            border-color: #002857; border-width: 1px;" type="text" id="radicado" name="radicado"
                            value='Evidencias: No adjunta'>
                    </td>
                    {% endif %}
                </tr>
                <tr>
                    <td class="celda-i"
                        style="width: 2px; padding-top: none; padding-bottom: 0px; padding-right: 0px;">
                        <label style="padding-top: 0px; margin-bottom: 0px;" for="radicado">5.</label>
                    </td>
                    {% if anexo is not None %}
                    <td class="celda-c" style="width: 392px; padding-left: 0px;">
                        <input style=" min-height: 20px; background: white; border: none; border-bottom-style: solid; border-radius: 0px;
                            border-color: #002857; border-width: 1px;" type="text" id="radicado" name="radicado"
                            value='Evidencias: Adjunta'>
                    </td>
                    {% else %}
                    <td class="celda-c" style="width: 392px; padding-left: 0px;">
                        <input style=" min-height: 20px; background: white; border: none; border-bottom-style: solid; border-radius: 0px;
                            border-color: #002857; border-width: 1px;" type="text" id="radicado" name="radicado"
                            value='Evidencias: No adjunta'>
                    </td>
                    {% endif %}
                </tr>
                <tr>
                    <td class="celda-i"
                        style="width: 2px; padding-top: none; padding-bottom: 0px; padding-right: 0px;">
                        <label style="padding-top: 0px; margin-bottom: 0px;" for="radicado">6.</label>
                    </td>
                    {% if anexo is not None %}
                    <td class="celda-c" style="width: 392px; padding-left: 0px;">
                        <input style=" min-height: 20px; background: white; border: none; border-bottom-style: solid; border-radius: 0px;
                            border-color: #002857; border-width: 1px;" type="text" id="radicado" name="radicado"
                            value='Evidencias: Adjunta'>
                    </td>
                    {% else %}
                    <td class="celda-c" style="width: 392px; padding-left: 0px;">
                        <input style=" min-height: 20px; background: white; border: none; border-bottom-style: solid; border-radius: 0px;
                            border-color: #002857; border-width: 1px;" type="text" id="radicado" name="radicado"
                            value='Evidencias: No adjunta'>
                    </td>
                    {% endif %}
                </tr>
            </table>
        </tr>
    </table>
</div>