<table>
    <tr>
        <td class="celda-i" style="max-width: 400px;">
            <input type="text" id="nombreCompleto" name="" value="{{nombre_completo}}" style="min-height: 35px;">
            <p
                style=" font-size: 15px; color: #002857; font-weight: 500; text-align: left; margin: 0px 0px 0px 0px">
                Nombre(s) y apellido(s)
            </p>
        </td>
        <td class="celda-i" style="max-width: 400px;">
            <input type="text" id="nombreCompleto" name="" value="" style="min-height: 35px;">
            <p style=" font-size: 15px; color: #002857; text-align: left; margin: 0px 0px 0px 0px">
                Firma
            </p>
        </td>
    </tr>
</table>